/***************************************************************************************************/
/*script in Sql, generate by SdmCreateScript 2020(by Qihang Feng, QF255001@TERADATA.COM)     */
/*VERSION 01.10 revised on 2020-08-25                                                              */
/*Brilliance stems from wisdoms.                                                                   */
/*************Head Section**************************************************************************/
/*Script Use: Periodically load data to :t00_china_city_info(中国城市信息)             */
/*Create Date:2024-01-16 23:03:52                                                                  */
/*SDM Developed By: dev                                                                            */
/*SDM Developed Date: 2024-01-16                                                                   */
/*SDM Checked By: dev                                                                              */
/*SDM Checked Date: 2024-01-16                                                                     */
/*Script Developed By: dev                                                                         */
/*Script Checked By: dev                                                                           */
/*Source table 1: p10_sa.s98_s_china_city                                                          */
/*Job Type: Inbound transform (Tier 1 to Tier 2)                                                   */
/*Target Table:t00_china_city_info                                                                 */
/*ETL Job Name:t00_china_city_info                                                                 */
/*ETL Frequency:Daily                                                                              */
/*ETL Policy:F2                                                                                    */
/********************************************************************************************/
/*******Main Section**************************************************************************/
\set ON_ERROR_STOP on
\set AUTOCOMMIT on
\timing on



/*创建临时表加载当前数据                                                                           */
CREATE TEMPORARY TABLE t00_china_city_info_agi_CUR_I 
 ( LIKE :PDMDB.t00_china_city_info)
ON COMMIT PRESERVE ROWS;



/*创建临时表加载不同数据                                                                           */
CREATE TEMPORARY TABLE t00_china_city_info_agi_INS 
( LIKE :PDMDB.t00_china_city_info)
ON COMMIT PRESERVE ROWS;

            
/*****************************************************************************************************/
/* GROUP 1:Source Table:s98_s_china_city**************************************************************/
/*****************************************************************************************************/
INSERT INTO t00_china_city_info_agi_CUR_I (
            area_cn                                 /*地区名称*/
           ,area_cd                                 /*地区代码*/
           ,parent                                  /*上级地区*/
           ,area_en                                 /*城市英文*/
           ,Etl_Batch_No                            /*作业批次号*/
           ,Etl_First_Dt                            /*最初入库时间*/
           ,Etl_Job                                 /*作业名称*/
           ,Etl_Proc_Dt                             /*本次入库时间*/
           ,Etl_Tx_Dt                               /*作业运行时间*/
           ,Src_Sysname                             /*来源系统*/
           ,Src_Table                               /*来源表*/
        )
SELECT
         COALESCE(TRIM(CAST(p0.area_cn AS varchar(20))),'')        /*area_cn*/
        ,COALESCE(TRIM(CAST(p0.area_cd AS varchar(20))),'')        /*area_cd*/
        ,COALESCE(TRIM(CAST(p0.parent AS varchar(20))),'')         /*parent*/
        ,COALESCE(TRIM(CAST(p0.area_en AS varchar(50))),'')        /*area_en*/
        ,0                                                         /*Etl_Batch_No*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_First_Dt*/
        ,:ETLJOB                                                   /*Etl_Job*/
        ,current_timestamp(0)                                      /*Etl_Proc_Dt*/
        ,TO_DATE(:TXDATE,'YYYYMMDD')                               /*Etl_Tx_Dt*/
        ,Substr('s98_s_china_city',1,3)                            /*Src_Sysname*/
        ,'s98_s_china_city'                                        /*Src_Table*/
        
FROM p10_sa.s98_s_china_city  p0
;



/*将不同数据插入到临时表                                                                           */
;INSERT INTO t00_china_city_info_agi_INS (
         area_cn                                                   /*地区名称*/
        ,parent                                                    /*上级地区*/
        ,area_en                                                   /*城市英文*/
        ,area_cd                                                   /*地区代码*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
    SELECT
         P1.area_cn                                                   /*地区名称*/
        ,P1.parent                                                    /*上级地区*/
        ,P1.area_en                                                   /*城市英文*/
        ,P1.area_cd                                                   /*地区代码*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t00_china_city_info_agi_CUR_I P1
LEFT JOIN :PDMDB.t00_china_city_info P2
ON    P1.area_cn = P2.area_cn
    AND P1.parent = P2.parent
    AND P1.area_en = P2.area_en
    AND P1.area_cd = P2.area_cd
    
WHERE  P2.area_cn IS NULL
    OR P2.parent IS NULL
    OR P2.area_en IS NULL
    OR P2.area_cd IS NULL
    
; 
/*将新增数据插入到目标表                                                                           */
;INSERT INTO :PDMDB.t00_china_city_info (
         area_cn                                                   /*地区名称*/
        ,parent                                                    /*上级地区*/
        ,area_en                                                   /*城市英文*/
        ,area_cd                                                   /*地区代码*/
        ,Etl_Batch_No                                              /*作业批次号*/
        ,Etl_First_Dt                                              /*最初入库时间*/
        ,Etl_Job                                                   /*作业名称*/
        ,Etl_Proc_Dt                                               /*本次入库时间*/
        ,Etl_Tx_Dt                                                 /*作业运行时间*/
        ,Src_Sysname                                               /*来源系统*/
        ,Src_Table                                                 /*来源表*/
        
)
SELECT
         P1.area_cn                                                   /*地区名称*/
        ,P1.parent                                                    /*上级地区*/
        ,P1.area_en                                                   /*城市英文*/
        ,P1.area_cd                                                   /*地区代码*/
        ,P1.Etl_Batch_No                                              /*作业批次号*/
        ,P1.Etl_First_Dt                                              /*最初入库时间*/
        ,P1.Etl_Job                                                   /*作业名称*/
        ,P1.Etl_Proc_Dt                                               /*本次入库时间*/
        ,P1.Etl_Tx_Dt                                                 /*作业运行时间*/
        ,P1.Src_Sysname                                               /*来源系统*/
        ,P1.Src_Table                                                 /*来源表*/
        
FROM t00_china_city_info_agi_INS P1
ON CONFLICT ( area_cd)
DO UPDATE SET
     area_cd=excluded.area_cd
    ,area_cn=excluded.area_cn
    ,parent=excluded.parent
    ,area_en=excluded.area_en
    ,Etl_Batch_No=excluded.Etl_Batch_No
    ,Etl_First_Dt=excluded.Etl_First_Dt
    ,Etl_Job=excluded.Etl_Job
    ,Etl_Proc_Dt=excluded.Etl_Proc_Dt
    ,Etl_Tx_Dt=excluded.Etl_Tx_Dt
    ,Src_Sysname=excluded.Src_Sysname
    ,Src_Table=excluded.Src_Table
    

;
/*****程序结束退出                                               */
\q

